/*
 * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_OOPS_WEAKHANDLE_INLINE_HPP
#define SHARE_OOPS_WEAKHANDLE_INLINE_HPP

#include "oops/weakHandle.hpp"

#include "oops/access.inline.hpp"

inline oop WeakHandle::resolve() const {
  assert(!is_null(), "Must be created");
  return NativeAccess<ON_PHANTOM_OOP_REF>::oop_load(_obj);
}

inline oop WeakHandle::peek() const {
  assert(!is_null(), "Must be created");
  return NativeAccess<ON_PHANTOM_OOP_REF | AS_NO_KEEPALIVE>::oop_load(_obj);
}

inline void WeakHandle::replace(oop with_obj) {
  assert(!is_empty(), "Must not use replace on empty handle");
  NativeAccess<ON_PHANTOM_OOP_REF>::oop_store(_obj, with_obj);
}

#endif // SHARE_OOPS_WEAKHANDLE_INLINE_HPP
